#
# spec file for package telepathy-gabble
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           telepathy-gabble
Version:        0.18.3
Release:        4.5
Summary:        XMPP connection manager for Telepathy
License:        LGPL-2.1+
Group:          Productivity/Networking/Instant Messenger
Url:            http://telepathy.freedesktop.org/wiki/
Source:         http://telepathy.freedesktop.org/releases/telepathy-gabble/%{name}-%{version}.tar.gz
BuildRequires:  libgnutls-devel
BuildRequires:  libnice-devel >= 0.0.11
BuildRequires:  libsoup-devel
BuildRequires:  libxslt-devel
BuildRequires:  python-xml
BuildRequires:  sqlite3-devel
BuildRequires:  telepathy-glib-devel >= 0.19.7
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
Recommends:     ca-certificates
# doc subpackage removed during 12.2 development
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Gabble is a Jabber/XMPP connection manager for the Telepathy framework,
currently supporting single user chats, multi user chats and
voice/video calls. Install this package to use Telepathy instant
messaging clients with Jabber/XMPP servers, including Google Talk.

%package xmpp-console
Summary:        XMPP connection manager for Telepathy -- XMPP Console
Group:          Productivity/Networking/Instant Messenger
Requires:       %{name} = %{version}
Requires:       python-gobject

%description xmpp-console
This utility is a XMPP console user interface, for telepathy-gabble.

%prep
%setup -q

%build
%configure \
        --disable-static \
        --docdir=%{_docdir}/%{name} \
        --with-ca-certificates=%{_sysconfdir}/ssl/ca-bundle.pem
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
cp AUTHORS ChangeLog COPYING %{buildroot}%{_docdir}/%{name}

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr (-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README
%doc %{_docdir}/%{name}/*.html
%dir %{_datadir}/telepathy
%dir %{_datadir}/telepathy/managers
%dir %{_libdir}/telepathy
%dir %{_libdir}/telepathy/gabble-0
%dir %{_libdir}/telepathy/gabble-0/plugins
%{_libexecdir}/telepathy-gabble
%{_libdir}/telepathy/gabble-0/lib/
%{_libdir}/telepathy/gabble-0/plugins/libgateways.so
%{_datadir}/dbus-1/services/org.freedesktop.Telepathy.ConnectionManager.gabble.service
%{_datadir}/telepathy/managers/gabble.manager
%{_mandir}/man8/telepathy-gabble.8%{?ext_man}

%files xmpp-console
%defattr (-,root,root)
%{_bindir}/telepathy-gabble-xmpp-console
%{_libdir}/telepathy/gabble-0/plugins/libconsole.so

%changelog
* Mon Aug 25 2014 zaitor@opensuse.org
- Update to version 0.18.3:
  + Fixes: Fix a crash in Jingle (fdo#76465).
* Mon Mar 31 2014 mgorse@suse.com
- Update to version 0.18.2:
  + Don't try to cancel a source ID twice, which issues a critical
    warning in GLib 2.39.
  + Fix failure to build with recent (Markdown-based) gtk-doc.
  + Plugin loader: don't crash if g_dir_open() fails twice
    (fdo#66085).
  + Fix a crash in 1-1 Tubes on 64-bit machines (fdo#70038).
  + Fix enum cast warnings under clang (fdo#70038)
* Fri Sep  6 2013 dimstar@opensuse.org
- Update to version 0.18.1:
  + This stable release fixes connection issues with Facebook which
    have been recently introduced because of a change in their XMPP
    servers.
  + If we send an IQ to a server allow "from" to be empty
    (fdo#68829).
* Mon Aug 12 2013 dimstar@opensuse.org
- Update to version 0.18.0:
  + GLib 2.32 is (directly) required.
  + better interop with Google webmail for audio/video calls.
  + better interop with Google and MSN servers.
  + better interop with iChat.
  + Don't claim to support X-TELEPATHY-PASSWORD if the username is
    unknown.
  + Look up a STUN server automatically, using DNS SRV.
  + Old-style Tubes channels have been removed.
  + Bug fixes.
- Changes from version 0.17.6:
  + Check for GLib 2.32 in the top-level configure.ac, and drop
    fallback paths for older GLib.
  + Bugs fixed: fdo#67875, fdo#67900, fdo#65290, fdo#67828,
    deb#714534.
* Sun Jun 23 2013 zaitor@opensuse.org
- Update to version 0.17.5:
  + Dependencies: GLib 2.32 is now directly required. It was
    already indirectly required by telepathy-glib 0.19.x.
  + Fixes:
  - update Wocky:
    . fdo#65131: interoperate with non-XMPP-Core-compliant Jingle
    IQs sent by Google's webmail UI.
    . Improve reference-counting for better stability.
  - fdo#65296: initialize libdbus for thread-safety.
  - fdo#64285: avoid running the same commands twice in parallel
    when doing a highly parallel build.
  - fdo#49595: disable an unreliable test-case.
* Sun Jun  2 2013 zaitor@opensuse.org
- Update to version 0.17.4:
  + update Wocky:
  - fdo#61792: fix linking an example program with ld versions
    that default to --no-copy-dt-needed-entries.
  - fdo#65036 (CVE-2013-1431): update Wocky to respect the
    tls-required flag on legacy Jabber servers.
  - fdo#63119: improve regression tests' isolation from the
    session bus.
  - fdo#64319: consider the <URL> field to be "supported" on
    Google servers.
  - fdo#64354: don't claim we support X-TELEPATHY-PASSWORD if we
    don't know the username.
- Drop telepathy-gabble-link-wocky.patch, fixed upstream.
* Mon May  6 2013 dimstar@opensuse.org
- Disable parallel build for now, as there is a high chance of
  failure (fdo#64285).
* Thu Mar 14 2013 dimstar@opensuse.org
- Update to version 0.17.3:
  + Enhancements:
  - fdo#58198: the Jingle protocol code now lives in Wocky. This
    should make no functional difference to Gabble.
  + Bugs fixed: fdo#43166, fdo#57521, fdo#61433.
- Changes from version 0.17.2:
  + Enhancements:
  - Gabble now uses GLib's base64 implementation rather than
    including its own (fdo#54760, fdo#57080).
  - Gabble now looks up a STUN server from the stun._udp SRV
    record for the user's domain (fdo#25961).
  - XEP-0184 delivery reports are now supported (fdo#47378).
  + Bugs fixed: fdo#33789, fdo#52146, fdo#52362, fdo#56181,
    fdo#57267, fdo#57521.
- Add telepathy-gabble-link-wocky.patch: link wocky examples
  against gnutls.
- Add libtool BuildRequires and call to autoreconf (in
  lib/ext/wocky), as above patch touches the build system of the
  integrated wocky library.
* Wed Sep 12 2012 vuntz@opensuse.org
- Update to version 0.17.1:
  + Enhancements:
  - fdo#32612: Old-style Tube channels have been removed.
  - Tube and Text channels are no longer announced together.
  + Fixes:
  - Make sure capability discovery works for the camera-v1
    capability bundle, avoiding an iChat bug in which it repeats
    failed capability discovery requests in a rapid loop
    (fdo#54634)
  - Fix some race conditions and other brokenness in the tests
- Add pkgconfig(glib-2.0) BuildRequires so it can be versioned.
* Mon Aug 27 2012 dimstar@opensuse.org
- Update to version 0.17.0:
  + Fix calls with android devices.
  + Implement WLM jidlookup. This makes possible to add MSN
    contacts using XMPP.
  + Fix google caps parsing.
* Thu Aug 23 2012 mailaender@opensuse.org
- Update to version 0.16.2
  + Fixes: Crash in tp_base_channel_close (fdo#53087).
* Thu Jun 21 2012 dimstar@opensuse.org
- Update to version 0.16.1:
  + "see-other-host" stream error is now supported. This fix
    connection issue with Windows Live XMPP server.
  + fdo#36998: Fail to establish a video call with Android.
* Thu Jun  7 2012 mikhail.zabaluev@gmail.com
- Moved the console plugin to telepathy-gabble-xmpp-console
* Fri Apr  6 2012 vuntz@opensuse.org
- Update to version 0.16.0:
  + Install plugins in their own special (versioned) gabble
    directory so we're not installing unversioned ABI-unstable
    libraries.
  + The DownloadAtConnection and Download ContactList members have
    been implemented.
  + Handle errors in IBB bytestreams (fdo#47999).
* Sun Mar 25 2012 dimstar@opensuse.org
- Update to version 0.15.5:
  + Enhancements:
  - fdo#46513: Refactor Jingle code to remove Telepathy in
    preparation of moving it to Wocky.
  - fdo#45602: Subclass TpBaseChannel in more channel
    implemenations.
  - fdo#47502: Add a --disable-voip configure flag to disable
    building gabble with VoIP support.
  + Fixes:
  - Correctly convert between Telepathy and Jingle candidate
    types.
  - Start sending automatically on accepting bidirectional calls.
- Change dbus-1-glib-devel BuildRequires to pkgconfig(dbus-glib-1).
* Wed Feb 22 2012 vuntz@opensuse.org
- Update to version 0.15.4:
  + Enhancements:
  - Add support for the final version of Call1 from
    telepathy-spec 0.25.2 and remove the telepathy-yell
    submodule.
  - fdo#41790: Make file transfer support optional
  - fdo#44056: telepathy-gabble-xmpp-console no longer mixes GIR
    and pygtk.
  - fdo#33911: The Loudmouth API compatibility layer has been
    removed.
  - fdo#45491: Error messages provided by the server in <presence
    type='error'/> stanzas are now exposed via the SimplePresence
    API. This makes it easier for users to distinguish contacts
    being offline from contacts' servers being broken.
  - fdo#44649: Gabble now has a gabble-plugins.so library,
    similarly to mission-control.
  + API changes to Wocky snapshot:
  - fdo#45400: WockyPepService's API has changed a little bit.
  - fdo#34975: WockyPorter is now responsible for sending back
    error replies for unhandled IQs, whereas previously this was
    up to Gabble.
  - fdo#27489: including <wocky/wocky.h> now includes all public
    API from Wocky, and including any other header directly is
    forbidden.
  + Fixes:
  - fdo#44331: Gabble plugin API fails at runtime on Windows:
    gabble_plugin_create_sidecar function is renamed to
    gabble_plugin_create_sidecar_async and new virtual function
    gabble_plugin_create_sidecar_finish is introduced.
  - fdo#45443 (workaround): avoid testing Credentials access
    control, since recent Linux has  stricter requirements for
    credentials-passing (it's now opt-in) which we're not yet
    meeting.
  - fdo#46379: don't raise a GError with domain 0.
  - fdo#44855: work around Google's unimplemented capability
    discovery by hard-coding the capabilities of the GTalk echo
    bot.
  - Work around the deprecation of GValueArray.
- Remove doc subpackage, and add appropriate Provides/Obsoletes to
  the main subpackage: the doc is too small to make sense as a
  separate package.
* Thu Dec 22 2011 vuntz@opensuse.org
- Update to version 0.15.3:
  + Fixes:
  - fdo#43891: Update wocky snapshot to fix
    wocky_data_form_set_type()
- Changes from version 0.15.2:
  + Enhancements:
  - fdo#43588, fdo#43889: Add public
    gabble_connection_add_sidecar_own_caps_full() function which
    includes data forms.
  + Fixes:
  - fdo#42462: Update wocky snapshot to fix gabble getting kicked
    from D-Bus when non-character utf-8 is used by remote clients
  - Fix the build when using GLib 2.32.
* Wed Dec 21 2011 vuntz@opensuse.org
- Split telepathy-gabble-xmpp-console tool in a
  telepathy-gabble-xmpp-console subpackage, since it's not really
  of interest to most people, and has many dependencies that
  telepathy-gabble doesn't have.
* Fri Nov 25 2011 dimstar@opensuse.org
- Update to version 0.15.1:
  + Enhancements:
  - fdo#38568: Gabble now ships with an XMPP console interface
  - fdo#32692, fdo#30296, fdo#41789: Gabble now implements the
    freshly-undrafted Protocol.Interface.Addressing and the
    still-unstable Connection.Interface.Addressing1, and uses
    them to expose Facebook contacts' integer IDs.
  - fdo#42446: Gabble can now be built on Android, using
    Androgenizer.
  + Fixes:
  - capabilities.h and caps-channel-manager.h are no longer
    erroneously omitted.
* Wed Nov 16 2011 dimstar@opensuse.org
- Update to version 0.15.0:
  + Enhancements:
  - fdo#42288: the Chan.I.FileTransfer.Metadata interface has
    been implemented.
  - Updated Wocky: The SASL auth server test now builds with new
    and old versions of libsasl2.
  + Bug fixes:
  - fdo#42706: fix a typo when indexing a pointer array by using
    the wrong counter!
  - fd.o#32050: fix a crasher when using OLPC activities.
  + Wocky:
  - fdo#41719: don't bail on hashing caps if there's no FORM_TYPE
  - fdo#39057: Accept from="server.com" as stanzas coming from
    server.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 0.14.0:
  + Enhancements:
  - It's now possible to install Gabble's test suite.
  - fdo#41417: when connected to Facebook, text channels now
    produce 'accepted' delivery reports when the user sends a
    message to a contact using another device.
  + Fixes:
  - Compile against unstable GLib, where including glib/gtypes.h
    directly (instead of glib.h) is forbidden.
  - Correct type mismatches for timestamps in muc-channel.c,
    which lead to Gabble not compiling correctly on 32-bit.
  - fdo#41743: Offline contacts to whom we have a presence
    subscription and also a channel open at the time the roster
    arrives are now correctly shown as offline, rather than
    unknown.
  - fdo#42281: Actually implement the ContactBlocking interface.
  - fdo#42186: Gabble no longer crashes if the server replies to
    its roster query IQ twice (as vk.com's XMPP server does).
  - Various memory leak fixes.
  - Gabble now returns MAXINT64 for the subject timestamp when it
    is unknown, as per the latest spec.
* Fri Oct 14 2011 dimstar@opensuse.org
- Update to version 0.13.7:
  + Enhancements:
  - fdo#32611: Gabble now implements the Room, Subject and
    RoomConfig interfaces. It no longer implements old-style
    Telepathy.Properties on text channels.
  - Plugins which implement channel managers may now expose
    capabilities from them, using the GabbleCapsChannelManager
    interface; other, less dramatic pieces of API for plugins
    have also been added.
  + Fixes:
  - fdo#41388: SASL authentication channels no longer claim that
    X-TELEPATHY-PASSWORD authentication is supported on servers
    that don't actually support authenticating with a password
    (such as the WLM server).
  - Wocky no longer confuses the realm and the server (which are
    usually, but not always, the same) when performing DIGEST-MD5
    authentication.
  - We now correctly submit the default configuration form to the
    MUC we have just created, rather than to the user's own
    server.
* Thu Sep 29 2011 vuntz@opensuse.org
- Update to version 0.13.6:
  + Enhancements:
  - Video-capable Android phones are now considered to be
    video-capable by Gabble. (fdo#36996)
  - Gabble now informs Google UIs that we have a camera connected
    if we have any video-capable user interfaces. While this is
    not strictly accurate, it's an improvement: they now show a
    little camera icon for us. (fdo#40471)
  - Google proxy support (and hence the libsoup dependency) is
    now optional. (fdo#40537)
  - Gabble no longer support the legacy Presence API. This
    reduces D-Bus traffic, particularly during login. (fdo#40598)
  - Gabble now signals all aliases from the roster in a single
    AliasesChanged signal. This *dramatically* reduces D-Bus
    traffic during login on services like Facebook. (fdo#40943)
  + Fixes:
  - Joining a password-protected chat room where someone else
    already has the nickname you wanted to use (a pretty obscure
    scenario) now works again. (fdo#39790)
  - Closing a Call channel immediately after it is created
    (specifically, before the Google relay server has had a
    chance to reply) no longer crashes Gabble. (fdo#39768)
  - The Google Talk setting controlling the sending of mail
    notifications is now explicitly enabled if a client is
    interested in mail notifications. (fdo#40565)
* Thu Aug 18 2011 dimstar@opensuse.org
- Update to version 0.13.5:
  + This is a fixed version of the botched 0.13.4 release
- Changes from version 0.13.4:
  + Enhancements:
  - fdo#11688: XEP-0012 (Last Activity) is implemented at last.
  - DecloakAutomatically is now enabled by default.
  + Fixes:
  - fdo#39933: StreamTube services are now only advertised to the
    network, if a Client filter has a channel class with
    Requested=false (incoming tube) or no Requested property at
    all (tube with any direction)
  - Gabble no longer crashes if a peer advertises malformed
    capabilities.
  - fdo#35968: The test suite's fake XMPP server now listens
    exclusively on localhost
  - fdo#38706: Invisibility now works on Google Talk again,
    following a server-side change.
  - The DecloakAutomatically and PowerSavingActive properties are
    now decoupled, rather than being erroneously linked.
  - Only certain known PEP events are now queued when power
    saving is active, as opposed to all PEP events.
* Thu Jul 28 2011 vuntz@opensuse.org
- Update to version 0.13.3:
  + Changes:
  - 'require-encryption' is now enabled by default.
  - Relatedly, Gabble will itself accept certificates for domains
    listed in 'extra-certificate-identities' if they have no
    other problems. (fdo#38749)
  + Fixes:
  - If telepathy-yell is installed to /usr/include, the included
    copy will still be used. (fdo#37492)
  - With GnuTLS 2.12, sending very large amounts of data will no
    longer cause the connection to stall. (fdo#36077)
  - File transfer channels should now work on Windows.
    (fdo#31621)
* Sun Jun 26 2011 dimstar@opensuse.org
- Update to version 0.13.2:
  + Enhancements:
  - autogen.sh now honours the NOCONFIGURE environment variable,
    for compatibility with gnome-autogen.sh.
  + Fixes:
  - fdo#27361: Empty aliases stored on the roster are now ignored
    Additionally, if we've cached a contact's JID as their alias
    on our roster (because we couldn't find a better alias), and
    we come across a better alias for the contact (via a PEP
    nickname push, or by fetching their vCard for some other
    reason), we now replace the JID with that better alias.
  - fdo#38603: We now handle receiving unavailable presence from
    our contacts before we receive the roster correctly.
    Previously, this would cause those contacts to be stuck in
    state 'unknown' rather than 'offline' until they next came
    online.
  - Don't make assertions about TpChannelIface:handle-type's
    value in GabbleFileTransferChannel's set_property
    implementation. The property's not really writeable (the
    getter returns a constant value for it anyway) and this fixes
    a crash with telepathy-glib 0.15.2, in which the default
    value has changed from NONE to UNKNOWN.
* Thu Jun 16 2011 vuntz@opensuse.org
- Update to version 0.13.1:
  + Fixes:
  - We now interoperate with Google Mail's brand new
    implementation of Jingle. Some of the workarounds added are
    temporary, and some are not. (fdo#38352)
  - Compare codec names case-insensitively. (fdo#38264)
* Fri Jun  3 2011 dimstar@opensuse.org
- Update to version 0.13.0:
  + Enhancements:
  - The draft Channel.Interface.Room is implemented.
  - IM and MUC channels now signal failure to send messages in
    some situations. (fdo#33460)
- Changes from version 0.12.1:
  + Enhancements:
  - Spurious server-generated messages sent by the Google Mail
    client's “reply to email over chat” feature are now filtered
    out. (fdo#36647)
  + Fixes:
  - No longer crashes if Disconnect() is called just before a
    connection declares itself Connected. (fdo#37078)
  - No longer assumes Google's Queue extension is supported if
    Google's Roster extension is supported. (fdo#36260)
  - Many corner cases of the transitions to and from Away and
    Invisible when using Google's Shared Status extension have
    been fixed. (fdo#37069, fdo#36058, fdo#37283)
  - You can now see your own avatar in MUCs. (fdo#32017)
* Mon May  2 2011 vuntz@opensuse.org
- Update to version 0.12.0:
  + Enhancements:
  - Plugins can now implement channel managers.
  + Fixes:
  - No longer crashes when joining MUCs fails, or when kicked
    from a MUC. (fdo#35120)
  - Handles MUC nickname conflicts more accurately, resolving an
    issue triggered by a Google Talk server bug. (fdo#35619)
  - No longer gets contacts' client types confused (fdo#32139)
  - Exposes the status message length limit imposed by Google
    Talk, and truncates status messages if necessary. (fdo#33054)
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 0.11.10:
  + Enhancements:
  - Non-urgent stanzas are now queued locally if PowerSaving is
    turned on but the google:queue extension is not available.
  - The ReferenceIdentities property on server TLS channels is now
    implemented, populated partly from a new
    'extra-certificate-identities' parameter. This allows
    Empathy/Gabble to safely trust the Google Talk server's
    certificate when using a JID hosted by Google Apps without
    prompting the user. (fdo#35410 and fdo#35415).
  - Fatal criticals can now be turned off at configure time
    (fdo#35840).
  - The new StreamHandler methods from spec 0.22.1 for rtcp-fb
    and rtp-hdrext are now implemented. (fdo#34985).
  + Fixes:
  - `make check -C tests/twisted` now prints a helpful message if
    Twisted is not available, and the regular tests now pass if
    Twisted is not available.
  - Fix memory leaks in ServerTLSManager (fdo#35395)
* Wed Mar 16 2011 fcrozat@novell.com
- Update to version 0.11.8:
  +  Updated Wocky:
  - wocky_porter_register_handler() has been split into three
    functions:
    wocky_porter_register_handler_from(),
    wocky_porter_register_handler_from_server(), and
    wocky_porter_register_handler_from_anyone(). These make it
    harder to introduce bugs like fdo#34048.
  - Since wocky_porter_register_handler() has been removed
    entirely, out-of-tree plugins may need to be updated to work
    with this release.
  + Fixes:
  - fdo#27693: Gabble no longer polls for contacts' geolocation
    information; it relies on PEP working properly.
  - fdo#35137: Gabble now sets the Overwritten_By_Nickname flag
    for appropriate contact info fields.
* Mon Feb 21 2011 fcrozat@novell.com
- Update to version 0.11.7:
  + Fixes:
  - fdo#32390: Gabble now treats a request for a ContactSearch
    channelwith Server set to the empty string as equivalent to
    not specifying a server, and rejects requests where the JID
    specified for Server is invalid.
  - fdo#32874: Offline contacts are now assumed to support
    1-1 text channels.
  - fdo#34048: Malicious contacts can no longer trick Gabble
    into relaying audio/video data via a server of their choosing.
  + Enhancements:
  - fdo#32815: fallback-conference-server now defaults to
    conference.telepathy.im. Thus, if the user's server doesn't
    have a conference component configured, upgrading a 1-1 chat
    into an ad-hoc conference still works.
  - fdo#11291: support for xep-0092, Software Version.
  - fdo#33471: support for the FileTransfer.URI property.
- Changes from version 0.11.6:
  + Interesting changes:
  - Generated code for the Call channel type has been moved to an
    external submodule called telepathy-yell. This is included in
    the source tarballs for telepathy-gabble (like how wocky is)
    so there should be no changes necessary for packagers.
  + Fixes:
  - fdo#19930: MUC channels are now only closed properly when
    the server acknowledges our request to leave. This fixes the
    case of trying to join a MUC you left only seconds ago before
    the server had a chance to notice.
  - fdo#26385: gabble's media stream code now uses
    TpDBusPropertiesMixin for increased maintainability.
  - Include Protocol.AuthenticationTypes in the manager file.
  + Enhancements:
  - More miscellaneous updates to the Call channel type
    including:
    . Update to newest Call spec.
    . Base classes have been extracted from Gabble code and
    moved into telepathy-yell.
    . Some test updates to ensure Call works as it should.
    . The caps cache has been moved from Gabble to Wocky.
  + Test suite changes
  + with-session-bus.sh is now as silent as it can be without
    verbose mode turned on.
- Changes from version 0.11.5:
  + Fixes:
  - Support for Google Talk's google:queue extension now works
    against Google's server again. This regressed in 0.11.1,
    which changed gabble to send iq gets rather than iq sets.
  - Fix crash caused by timing out items in the iq pipeline
    before sending them out.
  - Correctly parse jingle transport-info message that refer to
    multiple contents.
  + Updated Wocky:
  - Fix a bug in WockyHeartbeatSource which caused criticals
    when it was destroyed.
  - Fix parsing of chat state messages in MUCs.
- Changes from version 0.11.4:
  + Potentially-incompatible changes:
  - Following telepathy-spec 0.21.5, the message-token field in
    message headers is no longer guaranteed to be
    globally-unique. This is known to be problematic for
    rtcom-event-logger, as used in Maemo 5.
  + Enhancements:
  - Implement Protocol.AuthenticationTypes
  - Improve error reporting in Group and StreamedMedia channels
  + Fixes:
  - fdo#29147: you will no longer get the scrollback from MUCs
    hosted by M-Link (and possibly other servers) when you
    change your presence
  - fdo#32278: fix an assertion failure when accepting
    X-TELEPATHY-PASSWORD authentication and immediately closing
    the channel
  - Make the regression tests pass with telepathy-glib ≥ 0.13.8
  - Fix the build without system CA certificates
- Changes from version 0.11.3:
  + Enhancements:
  - fdo#31106: add Protocol.Interface.Presence
  - fdo#31874: implement and refactor undrafted SASL interface
  + Fixes:
  - fdo#31998: relax assertions about how fast
    AddMembers/RemoveMembers succeed
- Changes from version 0.11.2:
  + Fixes:
  - fdo#31412: fix crashes during disconnection if a PEP alias
    request is in-flight
  - Loosen an assertion to fix test failure with
    telepathy-glib >= 0.13.5, which releases connections' object
    paths sooner
  - fdo#31772: fix a crash if a contact goes invisible while
    we're discovering their capabilities
  - Remove accidentally re-added libuuid dependency
  - --with-ca-certificates, formerly known as --with-ca-file,
    now warns (rather than making configure fail) if the specified
    path does not exist. This is kinder to builds which may not
    actually have the CAs installed.
- Changes from version 0.11.1:
  + Enhancements:
  - Implement Conn.I.PowerSaving
  - fdo#31474: replace --with-ca-certificates configure option
    with --with-ca-file.
  + Fixes:
  - Don't generate unused bindings for channel bundles
  + Update wocky snapshot:
  - Add an optional dependency on libiphb and link it up to the
    main loop to provide non-regular XMPP pings where
    appropriate.
  - Misc OpenSSL fixes.
- Changes from version 0.11.0:
  + Enhancements:
  - Implement the ContactList, ContactGroups interfaces,
    refactoring GabbleRoster considerably in the process
  - fdo#28413: implement DTMF on StreamedMedia and Call
    channels, up-to-date for spec 0.21.3
  - Implement the ClientTypes interface
  - Make the tests considerably less prone to race conditions
  - Adapt GabbleCapsChannelManager to be useful in Salut too
  - fdo#31216: implement the stable version of
    MailNotification
  - fdo#28726: use Google's Shared Status extension to support
    being invisible/hidden on Google Talk
  - Add a summary of how Tubes capabilities work
  + Fixes:
  - Poll GMail servers periodically for a short time after each
    mail notification, to work around the server throttling
    notifications
  - fdo#30950: advertise the immutable properties of Messages
    channels
  - fdo#28279: don't announce new Tubes channels until ready
- Remove telepathy-gabble-CVE-2011-1000.patch: fixed in 0.11.7.
* Mon Feb 21 2011 vuntz@opensuse.org
- Add telepathy-gabble-CVE-2011-1000.patch: this fixes insufficient
  input validation, that could be exploited. Fix CVE-2011-1000 and
  bnc#673257.
* Thu Nov 18 2010 vuntz@opensuse.org
- Update to version 0.10.4:
  + Enhancements:
  - fdo#24775: implement local IPv4 address discovery on Windows,
    allowing out-of-band SOCKS5 bytestreams to work there
  + Fixes:
  - Updated Wocky snapshot:
    · Added HTTP proxy support. This is not technically a fix,
    but it's nice to have. ;-)
    · Miscellaneous leak fixes.
    · Miscellaneous other fixes.
  - Prefer XEP-0186 invisibility over privacy list-based
    invisibility when both are available
  - fdo#31197: improve portability to Windows
* Sat Oct  9 2010 vuntz@opensuse.org
- Update to version 0.10.3:
  + Fixes:
  - Emit ActivitiesChanged when the server aknowledges our own
    update
  - Removed dependency to libuuid
  - Slacker_message_filter can survive
    invalid/non-signal/unexpected messages
  - Remove support for gadget
- Remove libuuid-devel BuildRequires.
* Fri Oct  1 2010 vuntz@opensuse.org
- Update to version 0.10.2:
  + Updated Wocky snapshot:
  - Made it compile when built with OpenSSL
  - Handle the connection being disconnected by the remote side
    more gracefully
  - Make the XML parser more tolerant of recoverable errors in
    the incoming stream. In particular, this fixes an issue with
    illegal namespaces in some contacts' PEP nodes
  + Fixed a memory allocation error which could cause corruption
    when using plugins which deal with capabilities
  + Ensure only one OLPC activity is created for a given channel
* Thu Sep 30 2010 vuntz@opensuse.org
- Update to version 0.10.1:
  + From updated Wocky snapshot:
  - Check the return value of
    wocky_xmpp_connection_send_stanza_finish() in
    starttls_sent_cb()
  - Don't retry indefinitely on failed OpenSSL writes
  + Don't leak local candidates, stun servers, and remote
    candidates when getting Stream/Endpoint properties
  + Don't assume privacy list lists are well-formed
  + When a contact becomes unavailable, check the correct roster
    subscription attribute to decide whether their status should be
    Offline or Unknown
* Fri Sep 17 2010 vuntz@opensuse.org
- Update to version 0.10.0:
  + Fix a crash if the connection closes while verifying a TLS
    certificate
  + Allow an in-progress connection to the server to be cancelled
    with Disconnect
  + Add regression tests for TLS certificate verification
- Here's a summary of the main changes in 0.10 compared to 0.8.x:
  + Jingle calls now interoperate with Pidgin, Gajim, and XEP-0100
    SIP gateways
  + file transfers now interoperate with the Google Talk desktop
    client
  + support for Google Talk PMUC chatrooms
  + contact information (vCards) on servers supporting XEP-0054
  + searching for contacts on servers supporting XEP-0055
  + improved capability-discovery support (ContactCapabilities)
  + compile-time selection of GNUTLS or OpenSSL for SSL support
  + support for JIDs with non-ASCII domains
  + experimental support for plugins
  + experimental support for multi-user Jingle calls (Muji)
  + compilation on Unix platforms other than Linux should now work
* Tue Sep 14 2010 vuntz@opensuse.org
- Update to version 0.9.18:
  + Enhancements:
  - fdo#30065: implement the stable API for ContactSearch
  - Implement the stable API for interactive TLS certificate
    checking
  - Implement the stable API for Conference channels
  - Add the fallback-servers parameter, which can be used to make
    connections to Google Talk on some networks more reliable
  - Prompt the user about unknown TLS certificates if neither
    require-encryption nor ignore-ssl-errors is set
  + Fixes:
  - Make the --with-ca-certificates configure option work
  - fdo#30117: always emit PresencesChanged when we change our
    own presence, and fix a related memory leak
  - update our copy of Wocky:
    . fdo#28051: SRV errors on some networks no longer break
    Facebook logins
    . don't fail on missing CRLs if not in strict TLS
    verification mode
- Drop telepathy-gabble-ca-certificates.patch: fixed upstream.
* Fri Sep  3 2010 vuntz@opensuse.org
- Pass --with-ca-certificates=%%{_sysconfdir}/ssl/ca-bundle.pem to
  configure so that gabble knows where to look for certificates.
- Add ca-certificates Recommends.
- Add telepathy-gabble-ca-certificates.patch to fix
  - -with-ca-certificates.
* Fri Aug 27 2010 dimstar@opensuse.org
- Update to version 0.9.17:
  + Enhancements:
  - Implement TLS certificate support
  - Use TpBaseChannel instead of GabbleBaseChannel
  - Plugin-provided, privacy-list based presence statuses
  + Fixes:
  - fdo#29721: start the presence unsure timeout once we connect
  - fdo#29000: make CA certificates path configurable
  - Fix several leaks, improve tests in case of connection leaks
* Fri Aug 20 2010 dimstar@opensuse.org
- Update to version 0.9.16:
  + Enhancements:
  - Implement XEP-0126: Invisibility
  - Implement XEP-0186: Invisible Command
  - Implement org.freedesktop.Telepathy.Protocol
  - Add a ActivityProperties.GetActivity method for retrieving an
    activity's room handle from its id
  - Add a BuddyInfo.AddActivity method so activities can
    advertise themselves without having to track all the other
    shared activities
  + Fixes:
  - fdo#25533: muc-factory: don't associate a request with tubes
    if a tube was requested
  - muc-factory: rearrange which NewChannels signals come first
  - Cope if Jingle sharing requests omit <manifest>
  - fdo#29113: Skip file collection candidates with invalid
    addresses
  - several improvements to the test suite
  - Fixes for building under gcc-4.5
  - Adapt to the new TLS API
* Wed Jul 21 2010 vuntz@opensuse.org
- Change libopenssl-devel BuildRequires to libgnutls-devel since we
  now have a recent enough version of gnutls.
- Drop telepathy-gabble-include-uuid-fix.patch: it's only needed
  for openSUSE 11.1, which is too old.
* Mon Jul  5 2010 dimstar@opensuse.org
- Update to version 0.9.15:
  + deb#586936: in Wocky, clear the parser state when resetting,
    fixing assertion failures if the caps cache gets corrupted
  + fdo#28712: in Wocky, fix SCRAM-SHA1 authentication by
    initializing state correctly
  + Changes from Version 0.9.14:
  + When a call is ended, mention who ended it in the debug log
  + fdo#28599: ignore errors from disco#info query on our own bare
    JID, fixing connections to older versions of jabberd, jabberd2,
    Prosody etc.
  + Use the self-handle as actor for changes to the 'deny' list,
    and improve roster regression tests, in preparation for future
    ContactList API
  + fdo#28643: stop applying GNUTLS_VERIFY_DO_NOT_ALLOW_SAME flag,
    allowing connection to (for instance) jabber.ccc.de
  + Apply more workarounds for TLS server misbehaviour
  + fdo#27488:  wocky_connector_connect_finish, _register_finish
    parameters have been re-ordered.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 0.9.13:
  + Gabble is now able to exchange files with the Google Talk
    desktop client
  + Plugins may now specify additional capabilities for Gabble to
    advertise, and add responses to new disco#info queries.
  + The SCRAM-SHA-1 SASL mechanism is now supported.
  + Fixes:
  - Messages from JIDs at non-ASCII domains are no longer
    silently dropped
  - Whether or not the connection is secure is now correctly
    propagated from Wocky up to Gabble
- Changes from version 0.9.12:
  + New dependency: libuuid
  + The capabilities cache now persists on-disk.
  + Multi-user calls are now supported, using the Muji protocol
  + Support the /info contact attribute for ContactInfo
  + XMPP keepalives are now sent and acked
  + fdo#28265: When making outgoing calls, Gabble now prefers to
    call resources which claim to be phones
  + The current draft of SASL authentication channels is
    implemented
  + Fixes:
  - fdo#28232: Don't treat error replies from PEP nodes as PEP
    updates
  - fdo#27913: Don't drop backlog messages from former members of
    MUCs
  - fdo#20597: Blocked contacts are no longer accidentally
    unblocked if you remove them from the 'stored' list.
  - fdo#27157: Gabble MailNotification.RequestInboxURL no longer
    returns an empty string in some situations
- Add sqlite3-devel and libnice-devel BuildRequires.
* Tue May 11 2010 dimstar@opensuse.org
- Update to version 0.9.11:
  + Enhancements:
  - The ContactInfo interface is now implemented
  - Updated Wocky:
    . Permit ASCII mnemonics in wocky_stanza_build(), and detect
    more errors
    · Renamed WockyXmpp{Stanza,Node} to Wocky{Stanza,Node}; add
    more helper code for building, storing, and serializing
    trees of nodes
    · Refactored PubSub response distillery, and added support
    for retriving node configuration and modifying affiliates
  + Fixes:
  - fdo#25775: crash in pep_reply_cb()
  - fdo#27694: GetContactAttributes should return {} as location
    if there is no location for the contact
* Fri Apr  9 2010 vuntz@opensuse.org
- Update to version 0.9.10:
  + Enhancements:
  - Updated Wocky:
    . Improve Windows portability
    . Fix a double-free
    . Even more exciting PubSub code
  + Fixes:
  - Properly expose more authentication failure errors from Wocky
    in Connection.StatusChanged
  - Run tests in a temporary D-Bus session, which fixes fdo#25816
  - Fix tests on machines with no ipv6
  - Avoid doing undefined void-pointer arithmetic
* Sat Mar 27 2010 vuntz@opensuse.org
- Update to version 0.9.9:
  + Enhancements:
    + Update Wocky:
  - New and exiting Dataforms code!
    + Various portability improvements
  + Fixes:
    + Fix mail notification on GTalk showing at most 30 unread
    mails
* Wed Mar 17 2010 dimstar@opensuse.org
- Update to version 0.9.8:
  + Enhancements:
  - Update Wocky:
    . Lots of exciting new Pubsub code!
    . Plus some crash fixes
  - Various correctness improvements to the test suite.
  + Fixes:
  - No longer crashes on receiving a stanza error without an
    <error/> node, which was a regression in 0.9.5.
  - We can now spell “received” and “separate”
- Changes from version 0.9.7:
  + Enhancements:
  - Add support for draft 1 of
    Connection.Interface.MailNotification
  - Improve regression test coverage
  - Update Wocky:
    . data-form utility code (cassidy)
    . node iterator utility functions (sjoerd)
    . better gtk-doc, improve portability (smcv)
  + Fixes:
  - Implement the 'accuracy' key in Location, not the deprecated
    XEP-0080 'error' (which is not in telepathy-spec)
* Fri Feb 26 2010 dimstar@opensuse.org
- Update to version 0.9.6:
  + Enhancements:
  - The plugin loader is now built by default, and the gateway-
    registration plugin is installed by default. Since the API is
    still experimental and likely to change from one release to
    the next, the development headers etc. necessary to write
    third-party plugins are only installed if you configure with
  - -enable-plugin-api (this is not recommended)
  + Fixes:
  - fdo#26658: queue up any data received on the FileTransfer
    socket until the channel moves to state OPEN (KaKaRoTo)
  - Clean up signal connections in GabbleJingleFactory to avoid a
    possible use-after-free if a Jingle session, or the
    Connection, outlives the Jingle factory
  - Improve the gateway-registration plugin to exchange presence
    subscriptions and fix a memory leak
  - Don't install the plugin unless the plugin loader has been
    enabled, and don't compile a useless static-library version
    of the plugin
* Sun Feb 21 2010 vuntz@opensuse.org
- Update to version 0.9.5:
  + Enhancements:
  - Update Wocky for improved error-wrangling code
  + Fixes:
  - When delaying a stream request until service discovery has
    finished in order to interpret capabilities, correctly resume
    the request after service discovery
  - Calculate capabilities hash correctly when compiled with
  - -enable-is-a-phone
  - Don't emit a potentially-non-UTF-8 Google relay magic_cookie
    in debug output
* Fri Jan 29 2010 vuntz@opensuse.org
- Update to version 0.9.4:
  + Enhancements:
  - Added an --enable-is-a-phone configure switch, which makes
    Gabble identify itself as a "phone" (rather than a "pc") in
    XEP-0115 disco replies.
  - Added preliminary support for the Channel.Type.Call draft. By
    default, incoming Jingle calls are exposed as
    Channel.Type.Call if a handler is available.
  - One-to-one text channels can now be upgraded to multi-user
    conferences using the draft Conference interface. This will
    use a PMUC room on Google's conference server if at least one
    participant is using a Google Talk client, or an instant room
    on your own conference server (XEP-0045 §10.1.2) otherwise.
  - Implements XEP-0276, to permit calling contacts whose
    presence you are not subscribed to (controlled by a simple
    Gabble-specific connection interface).
  - Plugins may now specify their own version number, for
    improved debug logs.
  - Added a simple sidecar, implemented as a plugin, to support
    registering to gateways which require nothing more than a
    username and password.
  + Fixes:
  - We can now accept calls from, and place calls to, bare JIDs
    (that is, contacts with no resource). This is required for
    calling XEP-0100-compliant SIP gateways.
  - We now deal correctly with setting a vCard if there's no
    existing vCard on the server. (fdo#25987)
  - ignore-ssl-errors is now implied by require-encryption being
    false.
  - ContactCapabilities are now exposed on the Contacts interface
    with the correct attribute name. (fdo#26210)
* Wed Dec 23 2009 vuntz@opensuse.org
- Update to version 0.9.3:
  + Highlights:
  - Various updates to the OpenSSL backend causing it not to
    stall when reading multiple ssl records at the same time
  + Enhancements:
  - Gabble now advertises a 'pmuc-v1' capability bundle, telling
    the Google Mail client that we support being invited to MUCs.
    (fdo#22768)
  - Rather than hard-coding a list of SOCKS5 proxy servers to use
    if the user's own XMPP server does not provide one, Gabble
    now falls back to a list of proxy servers returned by
    discoing the newly-set-up proxies.telepathy.im. (fdo#25304)
  - Various leaks fixed as pointed out by valgrind
  + Fixes:
  - Do not re-publish our own vCard if nothing's changed
    (fdo#25341)
  - The default resource is now unique to the machine Gabble is
    running on, rather than being randomly generated for each
    connection. Fixes fdo#23630: “Per-connection resource
    randomization increases the window in which you lose
    messages”.
  - Always assume that MUC servers will let us change the
    subject, mitigating fdo#13157; previously we assumed they
    would only let moderators change the subject.
  - fdo#21152: allow joining chatrooms on servers that don't
    respond to disco queries, like talk.google.com
  - fdo#22456: append fallback conference server if the room name
    has no @, rather than just failing (if using the Requests
    API)
  - fdo#22768 (partial): reassure talk.google.com that we can be
    invited to chatrooms. This enables us to be invited to
    private MUCs by the Google client, but doesn't currently
    support creating them.
  - fdo#24558: correctly flag the password parameter as secret
  - Use TpDebugSender for debug output, instead of reimplementing
    it
  - Allow sending chat state to contacts whose capabilities we
    don't know, such as invisible Google Talk users
  - Only disco SOCKS5 proxies when they're needed for a file
    transfer or tube. (fdo#21151)
  - Do not advertise support for file transfers unless a handler
    is available. (fdo#25243)
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 0.9.2:
  + Highlights:
  - Add support for using OpenSSL instead of GNUTLS for SSL
    support
  + Fixes:
  - Honour errors that tell us to wait and try again when
    fetching vCards. This was erroneously claimed to be in 0.9.1.
  - Don't re-fetch our own avatar in a loop when connecting to
    Google Talk. This should fix fdo#23684 once and for all.
  - Don't trust other people's <message/> IDs to be globally
    unique: in particular, Google Talk uses simple incrementing
    integers
  - Use the correct marshaller for the pre-presence signal,
    fixing a cr 64-bit platforms
  - Make sure the Connection object disappears from the bus when
    disconnected
- Changes from version 0.9.1:
  + Highlights:
  - Jingle call interoperability with Pidgin and Gajim.
  + Fixes:
  - When receiving a file, Gabble now closes the local socket
    once all the data has been written.
  - fdo#24043: Doesn't parse candidates in a Jingle
    session-accept stanza. This fix lets us interoperate with
    Pidgin's Jingle implementation.
  - fdo#24023: Accepting initial streams for a call is racy.
  - fdo#20629: DBus events in tests should contain full path.
  - fdo#22795: jingle/google-relay.py is secretly made of cheese.
  - fdo#23903: Gabble crashes in File Transfer.
  - fdo#23685: build Gibber with fno-strict-aliasing so asyncns.c
    builds with new GCC.
  - fdo#20565: Contacts should be initially offline and not unknown.
  - When members are removed from a call due to a stream error,
    always indicate so.
  - Fix corner cases in SetLocation()'s language handling.
  - fdo#24195: Doesn't think clients without google p2p tranport
    are media capable. This fix lets us interoperate with Gajim's
    Jingle implementation.
  - Make stun-server.py not fail if the default STUN server
    hostname can't be resolved.
  - fdo#23684: Gabble advertizes an avatar's sha1 in its presence
    stanza without following XEP-0153.
  - Honour errors that tell us to wait and try again when
    fetching vCards.
- Changes from version 0.9.0:
  + Dependencies:
  - Gabble doesn't depend on loudmouth anymore. Instead, it ships
    a copy of Wocky, a new XMPP library based on gio. As a side
    effect of this, gio >= 2.21 and gnutls >= 2.8.2 are now
    needed to build Gabble.
  - telepathy-glib >= 0.7.37 is now required
  + Enhancements:
  - Add the ability to send a message when terminating a VoIP call
  - Add ContactSearch channels using spec draft 2
  - Implement the final ContactCapabilities spec, and refactor
    Capabilities code to represent capabilities as sets of XML
    namespaces, rather than bitfields
  - fdo#19952: Support requesting channels with
    InitialAudio/InitialVideo through the final API from
    telepathy-spec 0.17.28
  - Gabble now loads certificates from ~/.config/telepathy/certs/
    as well as from the system-wide location
    (/etc/ssl/certs/ca-certificates.crt).
  + Fixes:
  - Improve pubsub.c test coverage
  - fdo#22968: don't try to pass credentials through Unix sockets
    on non-Linux, since the way we currently do it is known to be
    non-portable. Patches to implement Credentials on more OSs
    would be welcomed.
- Remove loudmouth-devel BuildRequires.
- Add libopenssl-devel BuildRequires.
* Thu Oct  8 2009 vuntz@opensuse.org
- Update to version 0.8.5:
  + Fixes:
  - Don't re-fetch our own avatar in a loop when connecting to
    Google Talk. This should fix fdo#23684 once and for all.
  - Fix a crash introduced by the vCard-related fixes in 0.8.4.
- Changes from version 0.8.4:
  + Highlights:
  - Jingle call interoperability with Pidgin and Gajim.
  + Fixes:
  - When receiving a file, Gabble now closes the local socket
    once all the data has been written.
  - fdo#24043: Doesn't parse candidates in a Jingle
    session-accept stanza. This fix lets us interoperate with
    Pidgin's Jingle implementation.
  - fdo#24023: Accepting initial streams for a call is racy.
  - fdo#20629: DBus events in tests should contain full path.
  - fdo#22795: jingle/google-relay.py is secretly made of cheese.
  - fdo#23903: Gabble crashes in File Transfer.
  - fdo#23685: build Gibber with fno-strict-aliasing so asyncns.c
    builds with new GCC.
  - fdo#20565: Contacts should be initially offline and not
    unknown.
  - When members are removed from a call due to a stream error,
    always indicate so.
  - Fix corner cases in SetLocation()'s language handling.
  - fdo#24195: Doesn't think clients without google p2p tranport
    are media capable. This fix lets us interoperate with Gajim's
    Jingle implementation.
  - Make stun-server.py not fail if the default STUN server
    hostname can't be resolved.
  - fdo#23684: Gabble advertizes an avatar's sha1 in its presence
    stanza without following XEP-0153.
  - Honour errors that tell us to wait and try again when
    fetching vCards.
* Mon Sep 14 2009 vuntz@opensuse.org
- Update to version 0.8.3:
  + Enhancements:
  - fdo#23681: Allow setting presence on a connection before it
    goes online. This avoids e.g. going from Available -> Busy
    immediately when signing on.
  + Fixes:
  - fdo#23684: fix handling of avatar conflict with several
    resources, and a possible infinite ping-pong of presence
    stanzas from the server
  - Time out disco requests after 20, not 20,000, seconds!
  - Correctly respond to disco requests for video-v1 bundle,
    avoiding a loop when iChat blindly retries failed disco
    requests
  - Fix Requested and State properties of muc D-Bus tubes that we
    previously created and are still present when we re-join the
    muc.
  - Don't send the same disco request to the same (full) JID more
    than once. fdo#23841.
  - Update the Jingle raw-udp and ice-udp namespaces we claim to
    support to the current version.
  - fdo#23348, fdo#23349: fix compilation on NetBSD by including
    more headers
  - Reduce the size of the ChangeLog by truncating at version
    0.6.0 and not including diffstats (previously, the
    changelog.gz in our Debian packages was larger than Gabble
    itself!)
* Fri Sep  4 2009 vuntz@novell.com
- Update to version 0.8.2:
  + Enhancements:
  - Improve jid validation, so that obviously-invalid jids are
    rejected.
  + Fixes:
  - Don't crash when a vCard set fails, and there are edits
    pending. This can happen if you're trying to set your avatar
    and then disconnect.
  - fdo#23013: ContactCapabilities.SetSelfCapabilities can crash
    gabble with wrong parms
  - Fix parsing of incoming session accept from Google Video
    Chat. This should make outgoing calls to Google Video Chat
    users work, as well as incoming calls.
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 0.8.1:
  + Fixes:
  - fdo#22535: Gabble no longer crashes if you disconnect while
    it's trying to start a Google relay session for a call.
  - Fix an occasional crash when PEP requests time out, or are
    cancelled when you disconnect.
  - Correct an assertion about vCard edits not to fire
    incorrectly.
  - Clarify some correct-but-confusing behaviour in libjingle 0.3
    mode, which fixes a Coverity false-positive.
- Changes from version 0.8.0:
  + Enhancements:
  - Location and Debug are now implemented as stable interfaces.
  - Timeouts are synchronised to the second where possible,
    leading to fewer wakeups.
  + Fixes:
  - Fix race condition introduced by fix for fdo#22023.
  - Make vCard request less likely to time out.
  - Fix a bug where a vCard request failure could cause SetAvatar
    or SetAliases not to return.
* Sun Aug  9 2009 vuntz@novell.com
- Update to version 0.7.32:
  + Fixes:
  - fdo#21153: Remove session initiation and content add timeouts
    from the Jingle code; this should be client policy.
  - fdo#22023: Correctly avoid trying to set your vCard twice at
    the same time.
  - Correctly parse file-transfer timestamps. References
    fdo#23168.
  - Correctly fall back to stun.collabora.co.uk if neither the
    user nor the server has any better STUN server suggestions.
* Thu Jul 23 2009 lmedinas@gmail.com
- Update to version 0.7.31:
  + Enhancements:
  - The XML sent and received by Gabble is now exposed by the
    Debug interface.
  + Fixes:
  - Audio codecs' names are forced to match the case expected by
    the Google Talk desktop client, which is incorrectly
    case-sensitive.
  - fd.o#22535: Gabble no longer crashes if you disconnect while
    it's trying to start a Google relay session for a call.
  - fdo#22629: Gabble no longer crashes if the initiator of a
    tube receives data before it is connected to the
    application's socket.
  - fdo#22858: Gabble no longer erroneously hides Google Talk
    contacts who were automatically added to your roster, and
    contacts who Google incorrectly thinks are aliases for
    another JID.
  - fdo#22858: Removing a contact from 'subscribe' while they're
    in remote-pending ("Oops! I didn't mean to subscribe to
    Randall's presence!") now works. This is on top of the fix
    for fdo#21547 in 0.7.28, which made removing the contact
    from 'stored' work.  Previously, while the subscription
    request was correctly rescinded, Gabble didn't expose it
    correctly on the 'subscribe' channel.
  - fdo#22858: Contacts no longer "flicker" to and from
    subscribe:remote-pending when you subscribe to them on a
    Google Talk account. This was a regression in 0.7.28, caused
    by fixing fdo#21547.
  - Gabble no longer crashes if called by a client which is, or
    pretends to be, an old version of Google Talk (such as
    gtalk2voip.com, which is automatically used if a SIP user on
    sipphone.com calls a SIP URI that looks as though it's meant
    to be a gmail.com JID).
  - Fix a header guard in debug.h.
  - Move GThread initialization to the very beginning, since it's
    meant to be done before *any* GLib API usage.
* Sun Jul 19 2009 vuntz@novell.com
- Update to version 0.7.30:
  + Enhancements:
  - Gabble now supports making and receiving video calls to
    contacts using Google Video Chat. You'll need an H264 codec.
    We're aware of an issue where sometimes the Google client
    never sends us video; we're investigating it, and hopefully
    it'll be resolved soon.
  - The default port is now 5222, rather than unset. If you
    specify port=5222 and don't specify a server or old-ssl,
    Gabble will make an SRV lookup anyway: this is kinder to UIs
    that want to show the default XMPP port as 5222.
  - Gabble now advertises support for up-to-date Jingle
    namespaces, and implements the raw UDP and ICE-UDP transports
    as well as the non-standard Google Talk P2P transport.
    (fdo#22458 and fdo#13158, respectively.)
  + Fixes:
  - fdo#22369: Gabble now replies to the XMPP resource that's
    sending you messages, rather than always sending messages to
    the peer's bare JID.
  - The keepalive-interval parameter actually works now
    (previously, setting it caused a critical warning, and did
    not change the actual value from the default).
- Changes from version 0.7.29:
  + Enhancements:
  - Implement o.fd.Tp.Debug interface.
  - Added a "keepalive-interval" connection parameter (signature
    'u'), allowing the time between keepalive pings to the server
    to be configured (or disabled, by specifying 0).
  + Fixes:
  - fdo#21966: Gabble no longer crashes if you use the Hold
    interface before a call starts. You can put a call on hold
    even before it's initiated. You can also put an incoming,
    unanswered call on hold, but you have to unhold it before
    accepting the call.
  - The above also fixes (in passing) a reported issue where
    calls are signalled as having been put on hold just before
    they terminate.
  - fdo#20807: Gabble no longer crashes on unknown Jingle
    actions.
  - fdo#16886: You can now leave MUCs with a part message by
    calling RemoveMembers([self_handle], "this room is boring").
    Gabble now complies with telepathy-spec 0.17.21's requirement
    that you can always remove yourself from a group if you're in
    it, fixing fdo#20728.
  - fdo#18951: Gabble no longer sends <gone/> to contacts it
    hasn't previously sent typing notifications or messages to.
  - fdo#22209: Gabble no longer confuses Jingle sessions which
    have the same session ID but are to different contacts.
  - fdo#20763: Gabble now correctly namespaces Jingle contents by
    their creator, rather than (buggily) attempting to make the
    initiator's content win.
  - fdo#22326: Gabble now correctly handles presence stanzas for
    bare JIDs that contain capabilities, rather than ignoring
    them or (in really unlikely cases) crashing.
- Use libexecdir instead of libdir in the file list.
* Wed Jun 17 2009 vuntz@novell.com
- Change group to Productivity/Networking/Instant Messenger.
* Tue Jun  2 2009 vuntz@novell.com
- Update to version 0.7.28:
  + Dependencies:
  - telepathy-glib >= 0.7.31 is now required as Gabble implements
    the new tube API.
  + Enhancements:
  - Implement the Credentials access control with UNIX sockets in
    stream tubes.
  - Implement the Port access control with Inet4 and Inet6
    sockets in stream tubes.
  - Implement the final, stable new API for tubes.
  - In StreamTube, UNIX sockets created with the Localhost access
    control are usable by any user of the system.
  - When no resource is explicitly specified, Gabble will now use
    a randomized resource ("Telepathy.[random numbers]") rather
    than just "Telepathy". This helps users who don't know
    anything about XMPP to be able to connect from multiple
    Telepathy-powered clients at once. (fdo#21297)
  - Gabble now implements the 'stored' contact list, added in
    telepathy-spec 0.17.12. It no longer implements the 'known'
    list, which was never standard; we don't think this will
    break clients, since other CMs (such as telepathy-haze) never
    implemented 'known'. (fdo#19901)
  - Incoming call state notifications (ringing, on hold, etc.)
    are now handled in line with the latest draft of XEP-0167.
    (fdo#21836)
  + Fixes:
  - fdo#21684: Don't crash in SessionHandler.Ready() if streams
    is NULL
  - fdo#21817: Sometimes crashes upon receiving an empty <nick/>
    update.
  - fdo#21547: Contacts removed from roster stay on
    subscribe:remote-pending.
  - fdo#21878: Adding a new stream while a call's on hold makes
    it fall back to Pending Hold.
* Sat May 30 2009 lars@linux-schulserver.de
- fix requirement of doc subpackage
* Sun May 17 2009 vuntz@novell.com
- Update to version 0.7.27:
  + Dependencies:
  - We now explicitly depend on gthread-2.0 >= 2.16 as we need to
    initialize threads for libsoup's benefit (fdo#20937)
  + Enhancements:
  - Support file transfer resume.
  - Use ContactCapabilities draft to communicate file transfer
    support.
  - Implement latest draft of new API for tubes. The
    {Offer,Accept}{DBus,Stream}Tube methods and the
    StreamTubeNewConnection signal have been renamed.
  - The build system now uses Shave to produce kernel-style
    easy-to-read output from make. (You need to explicitly enable
    this with ./configure --enable-shave.)
  - It is now possible to request StreamedMedia channels with
    audio and/or video from the start, using the InitialAudio and
    InitialVideo properties, and to see from a channel's
    immutable properties (as also seen in NewChannels) whether it
    (initially) contained audio and/or video. (References
    fdo#20830)
  + Fixes:
  - Include private D-Bus tube and all MUC tube channels in
    Requests's Channels property.
  - StreamedMedia channels' group flags are now more
    spec-compliant. (Fixes fdo#20578)
  - When a contact doesn't have an alias, their full JID is used
    as the fallback, rather than the local part. (Fixes
    fdo#21295)
  - When setting an avatar fails, an appropriate error is now
    emitted. (Fixes fdo#20442 (not fdo#20422 as the git history
    claims).)
  - The lifecycles of several Jingle-related objects have been
    cleared up, fixing a number of Jingle crashes.
* Fri Apr 24 2009 vuntz@novell.com
- Review changes.
* Wed Apr 22 2009 cyberorg@opensuse.org
- Add telepathy-gabble-include-uuid-fix.patch for 11.1 because of
  broken libuuid pkg-config file.
* Thu Apr  9 2009 vuntz@novell.com
- Update to version 0.7.26:
  + When placing a streamed media call on hold, transmit the status
    change to the peer.
  + Relatedly, expose incoming Ringing and Hold notifications
    through the CallState interface.
  + Raise Offline or NotCapable (rather than NotAvailable) when
    methods in Jingle calls fail for one of those reasons.
  + Implement the Avatar interface's D-Bus properties, as
    introduced in spec version 0.17.22
* Sun Apr  5 2009 vuntz@novell.com
- Update to version 0.7.25:
  + Dependencies:
  - telepathy-glib >= 0.7.29 is now required.
  + Enhancements:
  - Discover SOCKS5 proxies on the connection and try to use them
    when offering a SOCKS5 bytestream.
  - Add fallback-socks5-proxies connection parameter to hardcode
    SOCKS5 proxies to use as fallback. Set lot of public proxies
    as default.
  - Use IPv6 addresses when trying to establish a SOCKS5
    bytestream.
  - Implement Channel.Type.FileTransfer. This means you can now
    send and receive files using Gabble.
* Tue Mar 24 2009 vuntz@novell.com
- Update to version 0.7.24:
  + Enhancements:
  - All messages on the Messages interface now have a message
    token, using the XMPP id attribute. Identifiers for messages
    that Gabble sends, and those it receives that lack one, are
    generated with libuuid if available, or with a unique-ish
    time-based fallback otherwise.
  + Fixes:
  - Fix SOCKS5 implementation to actually respect XEP-0065.
  - Don't crash if Google relay responses arrive after the call
    has ended (fdo#20764).
  - Relax overly-strict checks made by CodecsUpdated.
- Add libuuid-devel BuildRequires.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 0.7.23:
  + Dependencies:
  - telepathy-glib >= 0.7.26 is now required
  - libsoup >= 2.4 is now required
  + Enhancements:
  - Add functionality to ask for a Google-specific relay session,
    so Google Talk users can use Google's relay servers to make
    and receive Jingle calls.
  - The CodecsUpdated method, introduced in spec version 0.17.19
    and used to send updated parameters for codecs such as Theora
    and H264 to the other party in a call, is now implemented.
  + Fixes:
  - Fix flow control in tubes when using a SI fallback
    bytestream.
  - Implement flow control in bytestream IBB.
  - Make GetHandle() correspond to the TargetHandle[Type]
    properties on streamed media channels.
- Add libsoup-devel BuildRequires.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 0.7.22:
  + Dependencies:
  - telepathy-glib 0.7.24 is now required
  + Enhancements:
  - Resolve STUN servers' IP addresses as required by
    telepathy-spec changes currently under development
  - Add NATTraversal, STUNServers and CreatedLocally properties
    to Media.StreamHandler as required by telepathy-spec changes
    currently under development
  - Add fallback-stun-server, fallback-stun-port
    ConnectionManager parameters
  + Fixes:
  - Correctly deal with streams that are added after a call is
    accepted, fixing video streaming in calls that start off
    audio-only
  - fdo#20102: fix byte ordering of port in GibberListener
  - Drain some swamps in Jingle call handling for better
    maintainability, and improve Jingle regression test coverage
  - Don't end calls a minute after an extra content is added, and
    correctly set the creator attribute on contents. This has the
    side-effect of not causing older Gabbles to assert.
  - Improve Tubes test coverage, and fix various races in the
    tests.
* Sat Feb 21 2009 mboman@suse.de
- Update to version 0.7.21:
  + Implement new tube API for muc stream tubes
  + Implement new tube API for 1-1 and muc D-Bus tubes
  + Implement the Messages interface for Text channels.
  + In multi-user chats, the point at which Sent is emitted has
    changed. Previously, Sent was emitted when the message was
    echoed back to you by the server; now, it is emitted (as is
    Messages.MessageSent) when you send the message. When the
    message is echoed, a delivery report is emitted with
    Messages.MessageReceived, and Received is emitted with an
    empty body and the Non_Text_Content flag set. Clients that
    don't understand the Messages interface should just
    immediately ack the ID in that signal
  + fdo#20003: fix a crash starting Jingle calls on some 64-bit
    platforms
  + fdo#20133: fix various bugs where idle callbacks outlived
    their user-data.
  + Don't start sending video when the other side adds a video
    stream.
- Remove required versions for BuildRequires. We don't generally
  use it in our .spec files
- Set correct group for -doc package (Documentation/Other)
- Add Requires %%{name}-%%{version} for -doc package
* Wed Feb  4 2009 hfiguiere@suse.de
- Update to version 0.7.20
  + Implement the draft version of Location from telepathy-spec 0.17.19
  + Announce generic tube capabilities when contacts support tubes
  + Don't get confused if MUC services auto-rename us
  + Don't get confused if we have to change our own nick in order to join a MUC
  + Set the correct actor when Jingle sessions are terminated
  + Don't omit offline, unknown and error from Statuses and GetStatuses()
    (regression in 0.7.19)
  + Close and ChannelClosed signals are now fired when a tube is closed (new API)
* Sun Feb  1 2009 mboman@suse.de
- Update to version 0.7.19:
  + Don't crash when closing a muc channel containing an closed D-Bus tube.
  + Don't resurrect removed streams if the call responder includes them in
    session-accept
  + Don't crash in calls if using glib with debugging enabled (fdo#19327).
  + Don't crash when removing contact from known list (fdo#19524).
  + Fix D-Bus muc tubes (dev.sugarlabs.org #60).
  + Fix refcount leak in jingle code (fdo#19385).
  + Don't crash if "offline" presence status is requested.
* Wed Jan 28 2009 hfiguiere@suse.de
- Bump dbus glib required version.
* Fri Jan  9 2009 hfiguiere@suse.de
- Update to version 0.7.18:
  + Implement SOCKS5 bytestreams (XEP-0065) in stream tubes.
  + Implement a stream initiation fallback mechanism allowing to use IBB if
    we can't connect to peer using SOCKS5.
  + Don't crash on setting presence if there are open MUC Tubes.
  + Stream tube channel advertises the immutable channel properties,
    including those not on the Channel interface.
- Build requires dbus-1-glib-devel >= 0.78
- Split documentation off.
- Drop telepathy-gabble-64bits-crash.patch.
* Fri Jan  9 2009 hfiguiere@suse.de
- Add telepathy-gabble-64bits-crash.patch
  + fix a crash on 64-bits. bnc#445874
* Thu Jan  1 2009 mboman@suse.de
- Update to version 0.7.17:
  + Too many fixes/updtaes to list. Please see NEWS for details
  + Fixes bnc#445874 (in 0.7.11)
* Sun Oct 19 2008 mboman@suse.de
- Update to version 0.7.10:
  + Implement the newly official Requested, InitiatorHandle and InitiatorID
    properties introduced in spec 0.17.13
  + fdo#16922: stop shipping MD5 and SHA-1 implementations, and use
    GChecksum instead, since we need GLib 2.16 anyway
  + Add support for running tests with GObject refdbg enabled
  + Add TargetID to allowed properties when requesting channels
  + test-handles: stop asserting that the wrong error (InvalidArgument)
    will be raised, and accept the correct error (InvalidHandle) too, since
    this was fixed in telepathy-glib
  + Some bugfixes in the OLPC code
  + Use unsigned for booleans in bitfields (gboolean is signed, so
    "gboolean foo:1" is not portable)
* Mon Oct 13 2008 sbrabec@suse.cz
- Signed-off.
* Thu Oct  2 2008 dominique-opensuse@leuenberger.net
- Update to version 0.7.9:
  * Implement the Requests API introduced in spec 0.17.11 and extended in 0.17.12
  * Save contacts' aliases into the roster for massive bandwidth savings (in
    conjunction with avatar caching, this should mean we don't have to fetch
    everyone's vCard every time we connect to the server)
  * Merge support for the "gadget", an OLPC-specific server component that
    supports browsing for buddies and activities
  * When running tests under valgrind, use the same options as in telepathy-glib
* Tue Aug 19 2008 hfiguiere@suse.de
- Requires now telepathy-glib >= 0.7.14
- Upgrade to 0.7.8
  * Implement the Contacts interface for bulk contact-handle inspection
  * Implement spec 0.17.9 (add the TargetID property to all channels)
  * Start to port channel factories away from TpChannelFactoryIface in
    preparation for implementing the Requests API
  * Add a simple smoke-test for SimplePresence
  * Use tp_debug_divert_messages() rather than our own copy of it, since we
    now depend on a new enough telepathy-glib anyway
  * Obey the Telepathy spec by giving 'dnd' presence type Presence_Type_Busy
    and not Presence_Type_Away
  * Use the pedantically correct marshaller for a GArray, since GObject 2.17
    actually checks for POINTER vs BOXED (regression in 0.7.7)
  * Remove unconditional debug messages in a few places
* Fri Aug  8 2008 hfiguiere@suse.de
- Upgrade to 0.7.7:
  * Requires telepathy-glib >= 0.7.13
  * Implement XEP-0115 version 1.5
  * fd.o #14954: Set presence in MUCs to be the same as our global presence
  * fd.o #14955: Set nickname in MUCs to be the same as our alias for ourselves
  (as set with Aliasing)
  * Fix a reference leak when using (new-style) TLS
  * Fix a memory leak when invited to a MUC
  * Fix a possible assertion failure when we're sent an invalid MUC invitation
  * fd.o #16918: fix an access to freed memory when the vCard manager is
  destroyed
  * fd.o #14341: add a regression test (currently disabled, because the bug
  is in Loudmouth)
  * Port most of the regression tests to a more comprehensible API
* Thu Jul 24 2008 hfiguiere@suse.de
- Remove the requires and let Autoreqprov do it for us
* Thu Jul 24 2008 hfiguiere@suse.de
- Update to 0.7.6
  * telepathy-glib >= 0.7.8 and loudmouth >= 1.3.2 are now required
  * Implement the Hold API using telepathy-glib rather than as an extension
  * fdo#15656: fix an inconsistency in audio/video capabilities
  * fdo#15422: fix generation of extensions/extensions.html
  * fdo#15904: fix a regression making the caller of an incoming call in
    the remote pending set instead of the members one.
  * fdo#15095: fix MUC contacts always appearing to be offline (and actually
    include the patch this time) (regression in 0.7.0, probably)
  * fdo#15311: update tests to work with python-twisted 8.0 (as seen in
    current Debian unstable)
  * Ignore components with ID != 1 in native candidates - we can only signal
    one component, and Farsight 2 reports RTCP components along with RTP ones
  * Don't assume that htmldir will be defined by autoconf (it's new in 2.59c,
    and we only require >= 2.59; regression in 0.7.4)
  * fdo#14467: aggregate MembersChanged signals when joining MUCs, so we
    get one big signal rather than lots of single-contact signals, potentially
    reducing client round-trips
  * Re-enable some regression tests that were accidentally removed in 0.7.3
  * Build documentation for our extensions to XMPP by default
  * fdo#12791, Debian #446259: fix assertion failure with strange roster items
  * fdo#14343: fix race condition that can lose messages between accepting
    a D-Bus tube and actually connecting to it
  * fdo#14602: update the StreamedMedia call API to telepathy-spec 0.17.3
  * fdo#14806: when we add ourselves to the local-pending set for incoming
    calls, set the caller as the actor
  * fdo#15198: fix assertion failure when calling GetCapabilities on an invalid
    handle
  * When removing a media stream before the initiate is sent, send it if possible
  * when blocking gtalk contacts, discard their presence
  * disconnect the connection if we don't receive a reply to the discovery
    request for server features
  * stop using Automake 1.9 features, and prefer to autoreconf using 1.8 (if
    available) to ensure that we don't accidentally re-add a 1.9 dependency
  * make sure teardown of the disco object doesn't crash if one of its callbacks
    causes it to be destroyed (bug exposed by test-disco-no-reply.py regression
    test)
  * Implements the current draft of the Hold interface, which will be in
    telepathy-spec 0.17.4 if all goes well
  * Only emit one AvatarRetrieved signal per contact, no matter how many
    requests there were for their avatar (fdo#12465)
  * Explicitly say we require GNU make, and turn off Automake portability
    warnings (fdo#14020)
  * Don't emit NewStreamHandler signals multiple times if Ready is called
    multiple times on the SessionHandler (a bug in stream-engine used to
    cause this to happen sometimes)
  * Assorted code cleanup prompted by adding more gcc warnings
* Fri Mar 14 2008 hfiguiere@suse.de
- update to 0.7.2
  + Tubes: a generic transport for collaborative applications
  + Lot of bug fixes.
  + Take advantage of telepathy-glib 0.6.1 changes
  + Remove the -devel files
* Tue Dec 25 2007 lrupp@suse.de
- package static libraries in devel package
  (Obsoletes: %%name-glib - dunno why they are needed at all)
- beautify specfile
- don't use obsolete %%run_ldconfig
- package some files for doc
* Mon May 14 2007 btimothy@suse.de
- Add defattr to each %%files section.
* Tue Apr  3 2007 maw@suse.de
- Don't build as root.  Duh.
* Tue Apr  3 2007 maw@suse.de
- New package.
